window.onload = function () { 
    var spread = new GC.Spread.Sheets.Workbook(document.getElementById("ss"));
    initializeSpread(spread);
    // Compliance Checklist sheet is protected with password "test"
}

// Load templates
function initializeSpread(spread) {
    var sd = governmentTemplate;
    if (sd.length > 0) {
        if (!spread) { return; }
        spread.suspendPaint();
        spread.fromJSON(sd[0]);
        addData(spread);
        addFormatting(spread);
        addConditionalFormatting(spread);
        spread.resumePaint();
    }
}

// Load data into tables
function addData(spread) {
    var source = new GC.Spread.Sheets.Bindings.CellBindingSource(data);

    var bidSheet = spread.sheets[0];
    var bidColumns = [],
        bidNames = ['bidNumber', 'item', 'bidDate', 'amount', 'deadline'],
        bidLabels = ['Bid #', 'Item', 'Date of Bid', 'Amount', 'Deadline'];
    var bidTable = bidSheet.tables.findByName("BidTable");
    bidTable.autoGenerateColumns(false);
    bidNames.forEach(function(name, index) {
        var tableColumn = new GC.Spread.Sheets.Tables.TableColumn();
        tableColumn.name(bidLabels[index]);
        tableColumn.dataField(name);
        bidColumns.push(tableColumn);
    });
    bidTable.bindColumns(bidColumns);
    bidTable.bindingPath('bids');
    bidSheet.setDataSource(source);

    var contractSheet = spread.sheets[2];
    var contractColumns = [],
        contractNames = ['contract', 'vendor', 'date', 'originalAmount', 'forecastedAmount', 'invoicedAmount', 'status'],
        contractLabels = ['Contract', 'Vendor', 'Date', 'Original Amount', 'Forecasted Amount', 'Invoiced Amount', 'Status'];
    var contractTable = contractSheet.tables.findByName("ContractTable");
    contractTable.autoGenerateColumns(false);
    contractNames.forEach(function(name, index) {
        var tableColumn = new GC.Spread.Sheets.Tables.TableColumn();
        tableColumn.name(contractLabels[index]);
        tableColumn.dataField(name);
        contractColumns.push(tableColumn);
    });
    contractTable.bindColumns(contractColumns);
    contractTable.bindingPath('contracts');
    contractSheet.setDataSource(source);

    addCharts(spread);
}

// Format currency in tables
function addFormatting(spread) {
    var bidSheet = spread.sheets[0];
    bidSheet.getRange("E5:E14").formatter("$0,0");
    var contractSheet = spread.sheets[2];
    contractSheet.getRange("E16:G36").formatter("$0,0");
}

// Add conditional formatting
function addConditionalFormatting(spread) {
    var bidSheet = spread.sheets[0];
    var r = 3;
    var c = 4;
    var w = 1;
    var h = 11
    bidSheet.getRange(r, c, h, w).setBorder(new GC.Spread.Sheets.LineBorder("Black", GC.Spread.Sheets.LineStyle.dashed), { all: true });
    var dataBarRule = bidSheet.conditionalFormats.addDataBarRule(GC.Spread.Sheets.ConditionalFormatting.ScaleValueType.lowestValue, null,
            GC.Spread.Sheets.ConditionalFormatting.ScaleValueType.highestValue, null,
            "orange", [new GC.Spread.Sheets.Range(r + 1, c, h - 1, w)]);
    dataBarRule.gradient(true);
    dataBarRule.showBorder(false);
    dataBarRule.showBarOnly(false);
}

// Add charts
function addCharts(spread) {
    var contractSheet = spread.sheets[2];
    var doughnutChart = contractSheet.charts.add('doughnut', GC.Spread.Sheets.Charts.ChartType.doughnut, 25, 25, 475, 225, 'G15:G29');
    var doughnutSeriesItem = doughnutChart.series().get(0);
    doughnutSeriesItem.xValues = "B16:B29";
    doughnutSeriesItem.doughnutHoleSize = 0.4;
    doughnutSeriesItem.dataPoints = {
        0: {
            backColor: "rgb(91, 155, 213)"
        },
        1: {
            backColor: "rgb(237, 125, 49)"
        },
        2: {
            backColor: "rgb(165, 165, 165)"
        },
        3: {
            backColor: "rgb(255, 192, 0)"
        },
        4: {
            backColor: "rgb(68, 114, 196)"
        },
        5: {
            backColor: "rgb(112, 173, 71)"
        },
        6: {
            backColor: "rgb(255,20,128)"
        },
        7: {
            backColor: "rgb(91, 155, 213)"
        },
        8: {
            backColor: "rgb(237, 125, 49)"
        },
        9: {
            backColor: "rgb(165, 165, 165)"
        },
        10: {
            backColor: "rgb(255, 192, 0)"
        },
        11: {
            backColor: "rgb(68, 114, 196)"
        },
        12: {
            backColor: "rgb(112, 173, 71)"
        },
        13: {
            backColor: "rgb(255,20,128)"
        },
        14: {
            backColor: "rgb(91, 155, 213)"
        }
    }
    doughnutChart.series().set(0, doughnutSeriesItem);

    doughnutChart.legend({position:GC.Spread.Sheets.Charts.LegendPosition.right});
    doughnutChart.title({text: "Invoiced Amount"});

    var columnChart = contractSheet.charts.add('column', GC.Spread.Sheets.Charts.ChartType.columnStacked100, 550, 25, 475, 225, 'B15:G29');
    var columnSeriesItem = columnChart.series().get(0);
    columnSeriesItem.name = "Original Amount";
    columnSeriesItem.xValues = "B16:B29";
    columnSeriesItem.yValues = "E16:E29";
    columnChart.series().set(0, columnSeriesItem);
    columnSeriesItem = columnChart.series().get(1);
    columnSeriesItem.name = "Forecasted Amount";
    columnSeriesItem.xValues = "B16:B29";
    columnSeriesItem.yValues = "F16:F29";
    columnChart.series().set(1, columnSeriesItem);
    columnSeriesItem = columnChart.series().get(2);
    columnSeriesItem.name = "Invoiced Amount";
    columnSeriesItem.xValues = "B16:B29";
    columnSeriesItem.yValues = "G16:G29";
    columnChart.series().set(2, columnSeriesItem);
    columnChart.legend({position:GC.Spread.Sheets.Charts.LegendPosition.right});
    columnChart.title({text: "Contract Amounts"});
}